<template>
  <!-- 搜索 -->
  <ContentWrap>
    <el-form
      class="-mb-15px"
      :model="queryParams"
      ref="queryFormRef"
      :inline="true"
      label-width="68px"
    >
      <el-form-item label="名称" prop="title">
        <el-input
          v-model="queryParams.title"
          placeholder="请输入名称"
          clearable
          @keyup.enter="handleQuery"
          class="!w-240px"
        />
      </el-form-item>
      <el-form-item>
        <el-button @click="handleQuery">
          <Icon icon="ep:search" class="mr-5px" />
          搜索
        </el-button>
        <el-button @click="resetQuery">
          <Icon icon="ep:refresh" class="mr-5px" />
          重置
        </el-button>
        <el-button
          type="primary"
          plain
          @click="openForm('create')"
          v-hasPermi="['pre:alarm-config:create']"
        >
          <Icon icon="ep:plus" class="mr-5px" />
          新增
        </el-button>
      </el-form-item>
    </el-form>
  </ContentWrap>

  <!-- 列表 -->
  <ContentWrap>
    <el-table v-loading="loading" :data="list">
      <el-table-column label="消息标题" header-align="center" align="center" min-width="150" prop="title" fixed/>
      <el-table-column label="监控对象" header-align="center" align="center" min-width="150" prop="alarmObj" />
      <el-table-column label="预测项" header-align="center" align="center" min-width="150" prop="itemName" />
      <el-table-column label="输出" header-align="center" align="center" min-width="150" prop="outName" />
      <el-table-column label="比较长度" header-align="center" align="center" min-width="100" prop="compLength" />
      <el-table-column label="上限" header-align="center" align="center" min-width="50" prop="upperLimit" />
      <el-table-column label="下限" header-align="center" align="center" min-width="50" prop="lowerLimit" />
      <el-table-column label="单位" header-align="center" align="center" min-width="50" prop="unit" />
      <el-table-column label="转换系数" header-align="center" align="center" min-width="100" prop="coefficient" />
      <el-table-column label="是否启用" header-align="center" align="center" min-width="100" prop="isEnable" >
        <template #default="scope">
          <dict-tag :type="DICT_TYPE.COM_IS_INT" :value="scope.row.isEnable" />
        </template>
      </el-table-column>
      <el-table-column label="操作" align="center" min-width="180" fixed="right">
        <template #default="scope">
          <el-button
            link
            type="primary"
            @click="openForm('update', scope.row.id)"
            v-hasPermi="['pre:alarm-config:update']"
          >
            编辑
          </el-button>
          <el-button
            link
            type="danger"
            @click="handleDelete(scope.row.id)"
            v-hasPermi="['pre:alarm-config:delete']"
          >
            删除
          </el-button>
          <el-button
            link
            type="primary"
            @click="handleView(scope.row.id)"
          >
            查看历史
          </el-button>
        </template>
      </el-table-column>
    </el-table>
    <!-- 分页 -->
    <Pagination
      :total="total"
      v-model:page="queryParams.pageNo"
      v-model:limit="queryParams.pageSize"
      @pagination="getList"
    />
  </ContentWrap>

  <!-- 表单弹窗：添加/修改 -->
  <MmPredictAlarmConfigForm ref="formRef" @success="getList" />
  <MmPredictAlarmMessage ref="MessageRef" />

</template>
<script lang="ts" setup>
import MmPredictAlarmConfigForm from './MmPredictAlarmConfigForm.vue'
import MmPredictAlarmMessage from './MmPredictAlarmMessageForm.vue'
import * as MmPredictAlarmConfig from '@/api/model/pre/alarm/config'
import {DICT_TYPE} from "@/utils/dict";

defineOptions({name: 'DataMmPredictAlarmConfig'})

  const message = useMessage() // 消息弹窗
  const {t} = useI18n() // 国际化

  const loading = ref(true) // 列表的加载中
  const total = ref(0) // 列表的总页数
  const list = ref([]) // 列表的数据
  const queryParams = reactive({
    pageNo: 1,
    pageSize: 10,
    title: undefined,
  })
  const queryFormRef = ref() // 搜索的表单

  /** 查询列表 */
  const getList = async () => {
    loading.value = true
    try {
      const page = await MmPredictAlarmConfig.getMmPredictAlarmConfigPage(queryParams)
      list.value = page.list
      total.value = page.total
    } finally {
      loading.value = false
    }
  }

  /** 搜索按钮操作 */
  const handleQuery = () => {
    queryParams.pageNo = 1
    getList()
  }

  /** 重置按钮操作 */
  const resetQuery = () => {
    queryFormRef.value.resetFields()
    handleQuery()
  }

  /** 添加/修改操作 */
  const formRef = ref()
  const openForm = (type: string, id?: number) => {
    formRef.value.open(type, id)
  }

  /** 删除按钮操作 */
  const handleDelete = async (id: number) => {
    try {
      // 删除的二次确认
      await message.delConfirm()
      // 发起删除
      await MmPredictAlarmConfig.deleteMmPredictAlarmConfig(id)
      message.success(t('common.delSuccess'))
      // 刷新列表
      await getList()
    } catch {
    }
  }

  /** 查看历史按钮操作 */
  const MessageRef = ref()
  const handleView = (id?: string) => {
    MessageRef.value.open(id)
  }

  /** 初始化 **/
  onMounted(async () => {
    await getList()
  })
</script>
